#
# spec file for package python-fedora-messaging
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-fedora-messaging
Version:        3.2.0
Release:        2.6
Summary:        Python tools for Fedora's messaging infrastructure
License:        GPL-2.0-or-later
URL:            https://github.com/fedora-infra/fedora-messaging
Source:         https://files.pythonhosted.org/packages/source/f/fedora_messaging/fedora_messaging-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Twisted
Requires:       python-blinker
Requires:       python-click
Requires:       python-crochet
Requires:       python-jsonschema
Requires:       python-pika >= 1.0.1
Requires:       python-pyOpenSSL
Requires:       python-pytz
Requires:       python-service_identity
Requires:       python-toml
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module Twisted}
BuildRequires:  %{python_module blinker}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module crochet}
BuildRequires:  %{python_module jsonschema}
BuildRequires:  %{python_module pika >= 1.0.1}
BuildRequires:  %{python_module pyOpenSSL}
BuildRequires:  %{python_module pytest-twisted}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module service_identity}
BuildRequires:  %{python_module toml}
BuildRequires:  %{python_module towncrier}
BuildRequires:  %{python_module treq}
# /SECTION
Requires(post): update-alternatives
Requires(postun):update-alternatives
%python_subpackages

%description
A set of Python tools for using Fedora's messaging infrastructure.

%prep
%setup -q -n fedora_messaging-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/fedora-messaging
%{python_expand rm -r %{buildroot}%{$python_sitelib}/fedora_messaging/tests/
%fdupes %{buildroot}%{$python_sitelib}
}

%post
%python_install_alternative fedora-messaging

%postun
%python_uninstall_alternative fedora-messaging

%check
export PATH=$PATH:%{buildroot}%{_bindir}
export PYTHONDONTWRITEBYTECODE=1
export LANG=en_US.UTF-8
# https://github.com/fedora-infra/fedora-messaging/issues/255
sed -i 's:. Perhaps you forgot a comma?::' fedora_messaging/tests/unit/test_cli.py
# test_consume_unexpected_crash or test_consume_successful_halt are intermittent
# and only relevant for improved handling of an unexpected failure/halt
%pytest -k 'not (test_consume_unexpected_crash or test_consume_successful_halt)'

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/fedora-messaging
%{python_sitelib}/fedora_messaging
%{python_sitelib}/fedora_messaging-%{version}*-info

%changelog
* Thu Dec 15 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python_module macro definition
- More specific python_sitelib in %%files
- Remove not needed python-six requirement
- Add update alternatives requirement
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.2.0
  Features
  * Add a priority property to messages, and a default priority in the configuration (#275)
  * Add a message schema attribute and some documentation to help deprecate and upgrade message schemas (#227)
  Other Changes
  * Use tomllib from the standard library on Python 3.11 and above, fallback to tomli otherwise. (PR#274)
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.1.0
  * Add the app_name and agent_name properties to message schemas (#272)
  * Added "groups" property to message schemas. This property can be used if an event affects a list of groups. (#252)
* Wed Aug  3 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.0.2:
  * Add packit configuration.
  * Correct sync list, add issue repo and version info
- Remove unneeded BuildRequires on mock.
* Tue May  3 2022 pgajdos@suse.com
- add upstream bug url
* Mon May  2 2022 pgajdos@suse.com
- version update
  3.0.0 (2021-12-14)
  ==================
  API Changes
  - ----------
  * Queues created by the CLI are now non-durable, auto-deleted and exclusive, as
    server-named queues are.
    (`PR#239 <https://github.com/fedora-infra/fedora-messaging/pull/239>`_)
  * It is no longer necessary to declare a queue in the configuration file: a
    server-named queue will be created. Configured bindings which do not specify
    a queue name will be applied to the server-named queue.
    (`PR#239 <https://github.com/fedora-infra/fedora-messaging/pull/239>`_)
  * Drop support for Python 2
    (`PR#246 <https://github.com/fedora-infra/fedora-messaging/pull/246>`_)
  * Drop the Twisted classes that had been flagged as deprecated.
    Drop the deprecated ``Message._body`` property.
    Refactor the consuming code into the ``Consumer`` class.
    (`PR#249 <https://github.com/fedora-infra/fedora-messaging/pull/249>`_)
  Features
  - -------
  * Support anonymous (server-named) queues.
    (`PR#239 <https://github.com/fedora-infra/fedora-messaging/pull/239>`_)
  * Support Python 3.10
    (`PR#250 <https://github.com/fedora-infra/fedora-messaging/pull/250>`_)
  * Raise ``PublishForbidden`` exception immediately if publishing to `virtual host
    <https://www.rabbitmq.com/access-control.html>`_ is denied rather than waiting until timeout occurs.
    (`#203 <https://github.com/fedora-infra/fedora-messaging/issues/203>`_)
  Bug Fixes
  - --------
  * Fixed validation exception of queue field on serialized schemas.
    (`#240 <https://github.com/fedora-infra/fedora-messaging/issues/240>`_)
  2.1.0 (2021-05-12)
  ==================
  Features
  - -------
  * Improve the testing module to check message topics and bodies separately,
    and to use the rewritten assert that pytest provides
    (`PR#230 <https://github.com/fedora-infra/fedora-messaging/pull/230>`_)
  * Handle `topic authorization <https://www.rabbitmq.com/access-control.html#topic-authorisation>`_
    by raising a ``PublishForbidden`` exception instead of being stuck in a retry loop
    (`PR#235 <https://github.com/fedora-infra/fedora-messaging/pull/235>`_)
  * Test on Python 3.8 and 3.9
    (`PR#237 <https://github.com/fedora-infra/fedora-messaging/pull/237>`_)
  Bug Fixes
  - --------
  * Require setuptools, as ``pkg_resources`` is used
    (`PR#233 <https://github.com/fedora-infra/fedora-messaging/pull/233>`_)
  2.0.2 (2020-08-04)
  ==================
  Bug Fixes
  - --------
  * Set the QoS on the channel that is created for the consumer
    (`#223 <https://github.com/fedora-infra/fedora-messaging/issues/223>`_)
  2.0.1 (2020-01-02)
  ==================
  Bug Fixes
  - --------
  * Fix handling of new connections after a publish timeout
    (`#212 <https://github.com/fedora-infra/fedora-messaging/issues/212>`_)
- deleted patches
  - pr_232.patch (upstreamed)
* Sat Mar 27 2021 John Vandenberg <jayvdb@gmail.com>
- Add pr_232.patch from upstream
* Tue Nov 17 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v2.0.2
* Fri Dec 27 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.0.0
